@@ -41,7 +41,10 @@ class QuickBooks(object):
 
     authorize_url = "https://appcenter.intuit.com/Connect/Begin"
 
+    current_user_url = "https://appcenter.intuit.com/api/v1/user/current"
+
     disconnect_url = "https://appcenter.intuit.com/api/v1/connection/disconnect"
+    reconnect_url = "https://appcenter.intuit.com/api/v1/connection/reconnect"
 
     request_token = ''
     request_token_secret = ''
@@ -52,7 +55,7 @@ class QuickBooks(object):
         "Department", "Deposit", "Employee", "Estimate", "Invoice",
         "Item", "JournalEntry", "Payment", "PaymentMethod",
         "Purchase", "PurchaseOrder", "RefundReceipt",
-        "SalesReceipt", "TaxCode", "TaxRate", "Term",
+        "SalesReceipt", "TaxCode", "TaxService/Taxcode", "TaxRate", "Term",
         "TimeActivity", "Transfer", "Vendor", "VendorCredit"
     ]
 
@@ -158,6 +161,12 @@ class QuickBooks(object):
         self.request_token_secret = oauth_resp['oauth_token_secret']
         return self.qbService.get_authorize_url(self.request_token)
 
+    def get_current_user(self):
+        '''Get data from the current user endpoint'''
+        url = self.current_user_url
+        result = self.make_request("GET", url)
+        return result
+
     def get_report(self, report_type, qs=None):
         '''Get data from the report endpoint'''
         if qs == None:
@@ -203,6 +212,15 @@ class QuickBooks(object):
         result = self.make_request("GET", url)
         return result
 
+    def reconnect_account(self):
+        """
+        Reconnect current account by refreshing OAuth access tokens
+        :return:
+        """
+        url = self.reconnect_url
+        result = self.make_request("GET", url)
+        return result
+
     def make_request(self, request_type, url, request_body=None, content_type='application/json',
                      params=None, file_path=None):
 
